@@ -4,10 +4,14 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#include "phosh-plugin-prefs-config.h"
+
 #include "ticket-box-prefs.h"
 
 #include "phosh-plugin.h"
 
+#include <glib/gi18n-lib.h>
+
 char **g_io_phosh_plugin_prefs_ticket_box_query (void);
 
 void
@@ -19,6 +23,9 @@ g_io_module_load (GIOModule *module)
                                   PHOSH_TYPE_TICKET_BOX_PREFS,
                                   PLUGIN_PREFS_NAME,
                                   10);
+
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 }
 
 void
