@@ -27,25 +27,27 @@
 
 typedef struct _PhoshAppGridButtonPrivate PhoshAppGridButtonPrivate;
 struct _PhoshAppGridButtonPrivate {
-  GAppInfo *info;
-  gboolean is_favorite;
+  GAppInfo              *info;
+  gboolean               is_favorite;
   PhoshAppGridButtonMode mode;
-  PhoshFolderInfo *folder_info;
+  PhoshFolderInfo       *folder_info;
 
   gulong favorite_changed_watcher;
 
-  GtkWidget  *icon;
-  GtkWidget  *popover;
-  GtkGesture *gesture;
+  GtkWidget             *icon;
+  GtkWidget             *popover;
+  GtkGesture            *long_gesture;
+  GtkGesture            *right_gesture;
 
-  GMenu *menu;
-  GMenu *actions;
-  GMenu *folders;
+  GMenu      *menu;
+  GMenu      *actions;
+  GMenu      *folders;
 
   GActionMap *action_map;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhoshAppGridButton, phosh_app_grid_button, PHOSH_TYPE_APP_GRID_BASE_BUTTON)
+G_DEFINE_TYPE_WITH_PRIVATE (PhoshAppGridButton, phosh_app_grid_button,
+                            PHOSH_TYPE_APP_GRID_BASE_BUTTON)
 
 enum {
   PROP_0,
@@ -72,18 +74,18 @@ phosh_app_grid_button_set_property (GObject      *object,
   PhoshAppGridButton *self = PHOSH_APP_GRID_BUTTON (object);
 
   switch (property_id) {
-    case PROP_APP_INFO:
-      phosh_app_grid_button_set_app_info (self, g_value_get_object (value));
-      break;
-    case PROP_MODE:
-      phosh_app_grid_button_set_mode (self, g_value_get_enum (value));
-      break;
-    case PROP_FOLDER_INFO:
-      phosh_app_grid_button_set_folder_info (self, g_value_get_object (value));
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
+  case PROP_APP_INFO:
+    phosh_app_grid_button_set_app_info (self, g_value_get_object (value));
+    break;
+  case PROP_MODE:
+    phosh_app_grid_button_set_mode (self, g_value_get_enum (value));
+    break;
+  case PROP_FOLDER_INFO:
+    phosh_app_grid_button_set_folder_info (self, g_value_get_object (value));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
   }
 }
 
@@ -97,34 +99,22 @@ phosh_app_grid_button_get_property (GObject    *object,
   PhoshAppGridButton *self = PHOSH_APP_GRID_BUTTON (object);
 
   switch (property_id) {
-    case PROP_APP_INFO:
-      g_value_set_object (value, phosh_app_grid_button_get_app_info (self));
-      break;
-    case PROP_IS_FAVORITE:
-      g_value_set_boolean (value, phosh_app_grid_button_is_favorite (self));
-      break;
-    case PROP_MODE:
-      g_value_set_enum (value, phosh_app_grid_button_get_mode (self));
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
+  case PROP_APP_INFO:
+    g_value_set_object (value, phosh_app_grid_button_get_app_info (self));
+    break;
+  case PROP_IS_FAVORITE:
+    g_value_set_boolean (value, phosh_app_grid_button_is_favorite (self));
+    break;
+  case PROP_MODE:
+    g_value_set_enum (value, phosh_app_grid_button_get_mode (self));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
   }
 }
 
 
-static void
-phosh_app_grid_button_dispose (GObject *object)
-{
-  PhoshAppGridButton *self = PHOSH_APP_GRID_BUTTON (object);
-  PhoshAppGridButtonPrivate *priv = phosh_app_grid_button_get_instance_private (self);
-
-  g_clear_object (&priv->gesture);
-
-  G_OBJECT_CLASS (phosh_app_grid_button_parent_class)->dispose (object);
-}
-
-
 static void
 phosh_app_grid_button_finalize (GObject *object)
 {
@@ -170,12 +160,12 @@ populate_folders_menu (PhoshAppGridButton *self)
         g_app_info_equal (G_APP_INFO (folder), G_APP_INFO (priv->folder_info)))
       continue;
 
-    detailed_action = g_strdup_printf ("folder-add::%s", folder_paths[i]);
+    detailed_action = g_strdup_printf ("app-btn.folder-add::%s", folder_paths[i]);
     g_menu_append (folders_section, phosh_folder_info_get_name (folder), detailed_action);
   }
 
   g_menu_append_section (submenu, NULL, G_MENU_MODEL (folders_section));
-  g_menu_append (new_folder_section, _("Create new folder"), "folder-new");
+  g_menu_append (new_folder_section, _("Create new folder"), "app-btn.folder-new");
   g_menu_append_section (submenu, NULL, G_MENU_MODEL (new_folder_section));
 
   g_menu_append_item (priv->folders, submenu_item);
@@ -196,27 +186,21 @@ context_menu (GtkWidget *widget,
 }
 
 
-static gboolean
-phosh_app_grid_button_popup_menu (GtkWidget *self)
+static void
+on_right_pressed (GtkWidget *self, int n_press, double x, double y, GtkGesture *gesture)
+{
+  const GdkEvent *event = gtk_gesture_get_last_event (gesture, NULL);
+  if (gdk_event_triggers_context_menu (event))
+    context_menu (self, (GdkEvent *) event);
+}
+
+static void
+on_long_pressed (GtkWidget *self, double x, double y, GtkGesture *gesture)
 {
   context_menu (self, NULL);
-  return TRUE;
 }
 
 
-static gboolean
-phosh_app_grid_button_button_press_event (GtkWidget      *self,
-                                          GdkEventButton *event)
-{
-  if (gdk_event_triggers_context_menu ((GdkEvent *) event)) {
-    context_menu (self, (GdkEvent *) event);
-
-    return TRUE;
-  }
-
-  return GTK_WIDGET_CLASS (phosh_app_grid_button_parent_class)->button_press_event (self, event);
-}
-
 
 static void
 activate_cb (PhoshAppGridButton *self)
@@ -234,17 +218,13 @@ activate_cb (PhoshAppGridButton *self)
 static void
 phosh_app_grid_button_class_init (PhoshAppGridButtonClass *klass)
 {
-  GObjectClass   *object_class = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->set_property = phosh_app_grid_button_set_property;
   object_class->get_property = phosh_app_grid_button_get_property;
-  object_class->dispose = phosh_app_grid_button_dispose;
   object_class->finalize = phosh_app_grid_button_finalize;
 
-  widget_class->popup_menu = phosh_app_grid_button_popup_menu;
-  widget_class->button_press_event = phosh_app_grid_button_button_press_event;
-
   props[PROP_APP_INFO] =
     g_param_spec_object ("app-info", "App", "App Info",
                          G_TYPE_APP_INFO,
@@ -304,10 +284,14 @@ phosh_app_grid_button_class_init (PhoshAppGridButtonClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, icon);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, popover);
 
+  gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, long_gesture);
+  gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, right_gesture);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, menu);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, actions);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshAppGridButton, folders);
 
+  gtk_widget_class_bind_template_callback (widget_class, on_long_pressed);
+  gtk_widget_class_bind_template_callback (widget_class, on_right_pressed);
   gtk_widget_class_bind_template_callback (widget_class, activate_cb);
 
   signals[APP_LAUNCHED] = g_signal_new ("app-launched",
@@ -456,7 +440,7 @@ static void
 add_to_folder (PhoshAppGridButton *self, PhoshFolderInfo *folder_info)
 {
   PhoshAppGridButtonPrivate *priv = phosh_app_grid_button_get_instance_private (self);
-   /* If the app-info gets removed, then the change causes the grid to be filled with new buttons.
+  /* If the app-info gets removed, then the change causes the grid to be filled with new buttons.
    * This would cause the button and in-turn the app-info to be disposed. Take a reference to avoid
    * that and clear it when we are done. */
   g_autoptr (GAppInfo) info = g_object_ref (priv->info);
@@ -506,16 +490,6 @@ folder_remove_activated (GSimpleAction *action,
 }
 
 
-static void
-long_pressed (GtkGestureLongPress *gesture,
-              double               x,
-              double               y,
-              GtkWidget           *self)
-{
-  context_menu (self, NULL);
-}
-
-
 static GActionEntry entries[] =
 {
   { .name = "action", .activate = action_activated, .parameter_type = "s" },
@@ -575,15 +549,9 @@ phosh_app_grid_button_init (PhoshAppGridButton *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  priv->gesture = gtk_gesture_long_press_new (GTK_WIDGET (self));
-  gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (priv->gesture), TRUE);
-  gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (priv->gesture),
-                                              GTK_PHASE_CAPTURE);
-  g_signal_connect (priv->gesture, "pressed", G_CALLBACK (long_pressed), self);
-
   gtk_popover_bind_model (GTK_POPOVER (priv->popover),
                           G_MENU_MODEL (priv->menu),
-                          "app-btn");
+                          NULL);
 }
 
 
@@ -623,11 +591,10 @@ favorites_changed (GListModel         *list,
   priv = phosh_app_grid_button_get_instance_private (self);
 
   favorite = phosh_favorite_list_model_app_is_favorite (PHOSH_FAVORITE_LIST_MODEL (list),
-                                                           priv->info);
+                                                        priv->info);
 
-  if (priv->is_favorite == favorite) {
+  if (priv->is_favorite == favorite)
     return;
-  }
 
   act = g_action_map_lookup_action (priv->action_map, "favorite-add");
   g_simple_action_set_enabled (G_SIMPLE_ACTION (act), !favorite);
@@ -642,7 +609,7 @@ favorites_changed (GListModel         *list,
 
 void
 phosh_app_grid_button_set_app_info (PhoshAppGridButton *self,
-                                    GAppInfo *info)
+                                    GAppInfo           *info)
 {
   PhoshFavoriteListModel *list = NULL;
   PhoshAppGridButtonPrivate *priv;
@@ -655,7 +622,7 @@ phosh_app_grid_button_set_app_info (PhoshAppGridButton *self,
   priv = phosh_app_grid_button_get_instance_private (self);
 
   if (priv->info == info)
-      return;
+    return;
 
   g_clear_object (&priv->info);
 
@@ -669,9 +636,9 @@ phosh_app_grid_button_set_app_info (PhoshAppGridButton *self,
     priv->info = g_object_ref (info);
 
     priv->favorite_changed_watcher = g_signal_connect (list,
-                                                        "items-changed",
-                                                        G_CALLBACK (favorites_changed),
-                                                        self);
+                                                       "items-changed",
+                                                       G_CALLBACK (favorites_changed),
+                                                       self);
     favorites_changed (G_LIST_MODEL (list), 0, 0, 0, self);
 
     name = g_app_info_get_name (G_APP_INFO (priv->info));
@@ -717,7 +684,7 @@ phosh_app_grid_button_set_app_info (PhoshAppGridButton *self,
         g_autofree char *detailed_action = NULL;
         g_autofree char *label = NULL;
 
-        detailed_action = g_strdup_printf ("action::%s", actions[i]);
+        detailed_action = g_strdup_printf ("app-btn.action::%s", actions[i]);
 
         label = g_desktop_app_info_get_action_name (G_DESKTOP_APP_INFO (priv->info),
                                                     actions[i]);
@@ -772,8 +739,8 @@ phosh_app_grid_button_is_favorite (PhoshAppGridButton *self)
 
 
 void
-phosh_app_grid_button_set_mode (PhoshAppGridButton     *self,
-                                PhoshAppGridButtonMode  mode)
+phosh_app_grid_button_set_mode (PhoshAppGridButton    *self,
+                                PhoshAppGridButtonMode mode)
 {
   PhoshAppGridButtonPrivate *priv;
   const char *name;
@@ -781,22 +748,21 @@ phosh_app_grid_button_set_mode (PhoshAppGridButton     *self,
   g_return_if_fail (PHOSH_IS_APP_GRID_BUTTON (self));
   priv = phosh_app_grid_button_get_instance_private (self);
 
-  if (priv->mode == mode) {
+  if (priv->mode == mode)
     return;
-  }
 
   name = priv->info == NULL ? _("Application") : g_app_info_get_name (priv->info);
 
   switch (mode) {
-    case PHOSH_APP_GRID_BUTTON_LAUNCHER:
-      phosh_app_grid_base_button_set_label (PHOSH_APP_GRID_BASE_BUTTON (self), name);
-      break;
-    case PHOSH_APP_GRID_BUTTON_FAVORITES:
-      phosh_app_grid_base_button_set_label (PHOSH_APP_GRID_BASE_BUTTON (self), NULL);
-      break;
-    default:
-      g_critical ("Invalid mode %i", mode);
-      return;
+  case PHOSH_APP_GRID_BUTTON_LAUNCHER:
+    phosh_app_grid_base_button_set_label (PHOSH_APP_GRID_BASE_BUTTON (self), name);
+    break;
+  case PHOSH_APP_GRID_BUTTON_FAVORITES:
+    phosh_app_grid_base_button_set_label (PHOSH_APP_GRID_BASE_BUTTON (self), NULL);
+    break;
+  default:
+    g_critical ("Invalid mode %i", mode);
+    return;
   }
 
   priv->mode = mode;
