@@ -14,7 +14,6 @@
 #define _GNU_SOURCE
 #include <string.h>
 
-#include "feedback-manager.h"
 #include "app-grid.h"
 #include "app-grid-button.h"
 #include "app-grid-folder-button.h"
@@ -173,7 +172,6 @@ app_launched_cb (GtkWidget    *widget,
                  GAppInfo     *info,
                  PhoshAppGrid *self)
 {
-  phosh_trigger_feedback ("button-pressed");
   g_signal_emit (self, signals[APP_LAUNCHED], 0, info);
 }
 
@@ -188,7 +186,7 @@ create_folder_app_launcher (gpointer item, gpointer self)
   phosh_app_grid_button_set_folder_info (PHOSH_APP_GRID_BUTTON (btn), priv->open_folder);
   g_signal_connect (btn, "app-launched", G_CALLBACK (app_launched_cb), self);
 
-  gtk_widget_show (btn);
+  gtk_widget_set_visible (btn, TRUE);
 
   return btn;
 }
@@ -373,7 +371,7 @@ create_favorite_launcher (gpointer item,
   g_signal_connect (btn, "app-launched",
                     G_CALLBACK (app_launched_cb), self);
 
-  gtk_widget_show (btn);
+  gtk_widget_set_visible (btn, TRUE);
 
   return btn;
 }
@@ -424,7 +422,7 @@ create_launcher (gpointer item,
                       G_CALLBACK (app_launched_cb), self);
   }
 
-  gtk_widget_show (btn);
+  gtk_widget_set_visible (btn, TRUE);
 
   return btn;
 }
