@@ -24,10 +24,12 @@
 #define MPRIS_OBJECT_PATH "/org/mpris/MediaPlayer2"
 #define MPRIS_PREFIX "org.mpris.MediaPlayer2."
 
+#define ART_PIXEL_SIZE 48
 #define SEEK_SECOND 1000000
 #define SEEK_BACK (-10 * SEEK_SECOND)
 #define SEEK_FORWARD (30 * SEEK_SECOND)
 
+
 /**
  * PhoshMediaPlayer:
  *
@@ -83,6 +85,7 @@ typedef struct _PhoshMediaPlayer {
   GtkWidget                        *lbl_length;
 
   GCancellable                     *cancel;
+  GCancellable                     *fetch_icon_cancel;
   /* Base interface to raise player */
   PhoshMprisDBusMediaPlayer2       *mpris;
   /* Actual player controls */
@@ -202,7 +205,7 @@ on_poll_position_done (GDBusProxy *proxy, GAsyncResult *res, gpointer user_data)
   } else {
     g_warning ("Could not get Position from MPRIS player, hiding box_pos_len: %s", err->message);
     self->track_position = -1;
-    gtk_widget_hide (self->box_pos_len);
+    gtk_widget_set_visible (self->box_pos_len, FALSE);
     stop_pos_poller (self);
   }
 
@@ -419,6 +422,46 @@ btn_details_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
 }
 
 
+static void
+on_fetch_icon_ready (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhoshMediaPlayer *self;
+  g_autoptr (GInputStream) stream = NULL;
+  g_autoptr (GError) err = NULL;
+  g_autofree char *type = NULL;
+  g_autoptr (GdkPixbuf) pixbuf = NULL;
+
+  stream = g_loadable_icon_load_finish (G_LOADABLE_ICON (source_object), res, &type, &err);
+  if (!stream) {
+    g_warning ("Failed to fetch icon: %s", err->message);
+    return;
+  }
+
+  g_debug ("Loading icon of type: %s", type);
+  self = PHOSH_MEDIA_PLAYER (user_data);
+  pixbuf = gdk_pixbuf_new_from_stream (stream, self->fetch_icon_cancel, &err);
+  g_object_set (self->img_art, "gicon", pixbuf, NULL);
+}
+
+
+static void
+fetch_icon_async (PhoshMediaPlayer *self, const char *url)
+
+{
+  g_autoptr (GFile) file = g_file_new_for_uri (url);
+  GIcon *icon;
+
+  g_debug ("Fetching icon for %s", url);
+
+  icon = g_file_icon_new (file);
+  g_loadable_icon_load_async (G_LOADABLE_ICON (icon),
+                              ART_PIXEL_SIZE,
+                              self->fetch_icon_cancel,
+                              on_fetch_icon_ready,
+                              self);
+}
+
+
 static void
 on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMediaPlayer2Player *player)
 {
@@ -462,7 +505,7 @@ on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMe
     g_autofree char *length_text = cui_call_format_duration ((double) length / G_USEC_PER_SEC);
     gtk_label_set_label (GTK_LABEL (self->lbl_length), length_text);
     g_debug ("Metadata has length, showing box_pos_len");
-    gtk_widget_show (self->box_pos_len);
+    gtk_widget_set_visible (self->box_pos_len, TRUE);
     if (self->status == PHOSH_MEDIA_PLAYER_STATUS_PLAYING)
       start_pos_poller (self);
   } else {
@@ -471,12 +514,19 @@ on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMe
   self->track_length = length;
   update_position (self);
 
+  /* Cancel any pending icon loads */
+  g_cancellable_cancel (self->fetch_icon_cancel);
+  g_clear_object (&self->fetch_icon_cancel);
+
   if (url && g_strcmp0 (g_uri_peek_scheme (url), "file") == 0) {
     g_autoptr (GIcon) icon = NULL;
     g_autoptr (GFile) file = g_file_new_for_uri (url);
     icon = g_file_icon_new (file);
     g_object_set (self->img_art, "gicon", icon, NULL);
     has_art = TRUE;
+  } else if (url && (g_strcmp0 (g_uri_peek_scheme (url), "http") == 0 ||
+                     g_strcmp0 (g_uri_peek_scheme (url), "https") == 0)) {
+    fetch_icon_async (self, url);
   } else if (url && g_strcmp0 (g_uri_peek_scheme (url), "data") == 0) {
     g_autoptr (GdkPixbuf) pixbuf = NULL;
     g_autoptr (GError) error = NULL;
@@ -490,9 +540,8 @@ on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMe
     }
   }
 
-  if (!has_art) {
+  if (!has_art)
     g_object_set (self->img_art, "icon-name", "audio-x-generic-symbolic", NULL);
-  }
 }
 
 
@@ -517,16 +566,13 @@ on_playback_status_changed (PhoshMediaPlayer                 *self,
   if (!g_strcmp0 ("Playing", status)) {
     self->status = PHOSH_MEDIA_PLAYER_STATUS_PLAYING;
     icon = "media-playback-pause-symbolic";
-    set_playable (self, TRUE);
     start_pos_poller (self);
   } else if (!g_strcmp0 ("Paused", status)) {
     self->status = PHOSH_MEDIA_PLAYER_STATUS_PAUSED;
-    set_playable (self, TRUE);
     stop_pos_poller (self);
     poll_position (self);
   } else if (!g_strcmp0 ("Stopped", status)) {
     self->status = PHOSH_MEDIA_PLAYER_STATUS_STOPPED;
-    set_playable (self, FALSE);
     stop_pos_poller (self);
     self->track_position = 0;
     update_position (self);
@@ -575,12 +621,13 @@ on_can_play (PhoshMediaPlayer                 *self,
              GParamSpec                       *psepc,
              PhoshMprisDBusMediaPlayer2Player *player)
 {
-  gboolean sensitive;
+  gboolean can_play;
 
   g_return_if_fail (PHOSH_IS_MEDIA_PLAYER (self));
-  sensitive = phosh_mpris_dbus_media_player2_player_get_can_play (player);
-  g_debug ("Can play: %d", sensitive);
-  gtk_widget_set_sensitive (self->btn_play, sensitive);
+  can_play = phosh_mpris_dbus_media_player2_player_get_can_play (player);
+  g_debug ("Can play: %d", can_play);
+  gtk_widget_set_sensitive (self->btn_play, can_play);
+  set_playable (self, can_play);
 }
 
 
@@ -608,6 +655,9 @@ phosh_media_player_dispose (GObject *object)
   g_cancellable_cancel (self->cancel);
   g_clear_object (&self->cancel);
 
+  g_cancellable_cancel (self->fetch_icon_cancel);
+  g_clear_object (&self->fetch_icon_cancel);
+
   if (self->dbus_id) {
     g_dbus_connection_signal_unsubscribe (self->session_bus, self->dbus_id);
     self->dbus_id = 0;
@@ -745,7 +795,7 @@ attach_player_cb (GObject          *source_object,
   /* Set 'attached' before running notifiers, since we check it on e.g. start_pos_poller() */
   set_attached (self, TRUE);
   /* Hide progress bar box by default, it's shown if track length is given in metadata */
-  gtk_widget_hide (self->box_pos_len);
+  gtk_widget_set_visible (self->box_pos_len, FALSE);
 
   g_object_notify (G_OBJECT (self->player), "metadata");
   g_object_notify (G_OBJECT (self->player), "playback-status");
