@@ -10,9 +10,10 @@
 
 #include "phosh-config.h"
 #include "animation.h"
+#include "layersurface-priv.h"
 #include "notification-banner.h"
 #include "notification-frame.h"
-#include "shell.h"
+#include "shell-priv.h"
 #include "util.h"
 
 #include <handy.h>
