@@ -238,7 +238,7 @@ phosh_osd_window_class_init (PhoshOsdWindowClass *klass)
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
   gtk_widget_class_set_template_from_resource (widget_class,
-                                               "/sm/puri/phosh/ui/osd-window.ui");
+                                               "/mobi/phosh/ui/osd-window.ui");
   gtk_widget_class_bind_template_child (widget_class, PhoshOsdWindow, lbl);
   gtk_widget_class_bind_template_child (widget_class, PhoshOsdWindow, icon);
   gtk_widget_class_bind_template_child (widget_class, PhoshOsdWindow, bar);
