@@ -10,7 +10,7 @@
  * Author: Bob Ham <bob.ham@puri.sm>
  */
 
-#include "config.h"
+#include "cui-config.h"
 
 #include "cui-call-display.h"
 #include "cui-encryption-indicator-priv.h"
@@ -47,7 +47,6 @@ struct _CuiCallDisplay {
 
   CuiCall                *call;
 
-  GtkLabel               *incoming_phone_call;
   HdyAvatar              *avatar;
   GtkLabel               *primary_contact_info;
   GtkLabel               *secondary_contact_info;
@@ -166,34 +165,16 @@ hide_dial_pad_clicked_cb (CuiCallDisplay *self)
 static void
 set_pretty_time (CuiCallDisplay *self)
 {
-#define MINUTE 60
-#define HOUR   (60 * MINUTE)
-
   gdouble elapsed;
-  g_autoptr (GString) str = NULL;
-  guint seconds, minutes;
+  g_autofree char *duration = NULL;
 
   g_assert (CUI_IS_CALL_DISPLAY (self));
   g_assert (CUI_IS_CALL (self->call));
 
   elapsed = cui_call_get_active_time (self->call);
+  duration = cui_call_format_duration (elapsed);
 
-  str = g_string_new ("");
-
-  if (elapsed > HOUR) {
-    guint hours = (guint) (elapsed / HOUR);
-    g_string_append_printf (str, "%u:", hours);
-    elapsed -= (hours * HOUR);
-  }
-
-  minutes = (guint) (elapsed / MINUTE);
-  seconds = elapsed - (minutes * MINUTE);
-  g_string_append_printf (str, "%02u:%02u", minutes, seconds);
-
-  gtk_label_set_label (self->status, str->str);
-
-#undef HOUR
-#undef MINUTE
+  gtk_label_set_label (self->status, duration);
 }
 
 
@@ -222,18 +203,13 @@ on_call_state_changed (CuiCallDisplay *self,
   gtk_widget_set_sensitive (GTK_WIDGET (self->answer), TRUE);
   gtk_widget_set_sensitive (GTK_WIDGET (self->hang_up), TRUE);
 
-  #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-
   /* Widgets and call audio mode*/
   switch (state)
   {
   case CUI_CALL_STATE_INCOMING:
     hdy_avatar_set_size (self->avatar, HDY_AVATAR_SIZE_BIG);
-    G_GNUC_FALLTHROUGH;
 
-  case CUI_CALL_STATE_WAITING: /* Deprecated */
     gtk_widget_hide (GTK_WIDGET (self->controls));
-    gtk_widget_show (GTK_WIDGET (self->incoming_phone_call));
     gtk_widget_show (GTK_WIDGET (self->answer));
     gtk_style_context_remove_class
       (hang_up_style, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
@@ -241,16 +217,13 @@ on_call_state_changed (CuiCallDisplay *self,
 
   case CUI_CALL_STATE_ACTIVE:
     hdy_avatar_set_size (self->avatar, HDY_AVATAR_SIZE_DEFAULT);
-    self->needs_cam_reset = TRUE;
     G_GNUC_FALLTHROUGH;
 
   case CUI_CALL_STATE_CALLING:
-  case CUI_CALL_STATE_ALERTING: /* Deprecated */
   case CUI_CALL_STATE_HELD:
     gtk_style_context_add_class
       (hang_up_style, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
     gtk_widget_hide (GTK_WIDGET (self->answer));
-    gtk_widget_hide (GTK_WIDGET (self->incoming_phone_call));
     gtk_widget_show (GTK_WIDGET (self->controls));
 
     gtk_widget_set_visible
@@ -261,6 +234,7 @@ on_call_state_changed (CuiCallDisplay *self,
     call_audio_select_mode_async (CALL_AUDIO_MODE_CALL,
                                   on_libcallaudio_async_finished,
                                   NULL);
+    self->needs_cam_reset = TRUE;
     break;
 
   case CUI_CALL_STATE_DISCONNECTED:
@@ -280,16 +254,12 @@ on_call_state_changed (CuiCallDisplay *self,
   /* Status text */
   switch (state)
   {
-  case CUI_CALL_STATE_INCOMING:
-  case CUI_CALL_STATE_WAITING: /* Deprecated */
-    break;
-
   case CUI_CALL_STATE_ACTIVE:
     set_pretty_time (self);
     break;
 
+  case CUI_CALL_STATE_INCOMING:
   case CUI_CALL_STATE_CALLING:
-  case CUI_CALL_STATE_ALERTING: /* Deprecated */
   case CUI_CALL_STATE_HELD:
   case CUI_CALL_STATE_DISCONNECTED:
     gtk_label_set_label (self->status, cui_call_state_to_string (state));
@@ -299,8 +269,6 @@ on_call_state_changed (CuiCallDisplay *self,
   default:
     g_warn_if_reached ();
   }
-
-  #pragma GCC diagnostic warning "-Wdeprecated-declarations"
 }
 
 
@@ -387,7 +355,6 @@ reset_ui (CuiCallDisplay *self)
   gtk_label_set_label (self->status, "");
   gtk_widget_show (GTK_WIDGET (self->answer));
   gtk_widget_show (GTK_WIDGET (self->hang_up));
-  gtk_widget_hide (GTK_WIDGET (self->incoming_phone_call));
   gtk_widget_show (GTK_WIDGET (self->controls));
   gtk_widget_show (GTK_WIDGET (self->gsm_controls));
   gtk_widget_set_sensitive (GTK_WIDGET (self->answer), TRUE);
@@ -543,7 +510,6 @@ cui_call_display_class_init (CuiCallDisplayClass *klass)
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, general_controls);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, gsm_controls);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, hang_up);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, incoming_phone_call);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, keypad_entry);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, mute);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, primary_contact_info);
