@@ -11,9 +11,8 @@
 #include "phosh-screenshot-dbus.h"
 #include "phosh-test-resources.h"
 #include "portal-dbus.h"
-#include "shell.h"
+#include "shell-priv.h"
 
-#include "testlib-wall-clock-mock.h"
 #include "testlib-full-shell.h"
 #include "testlib-calls-mock.h"
 #include "testlib-mpris-mock.h"
