@@ -43,7 +43,7 @@ main (int argc, char **argv)
   gtk_init (&argc, &argv);
 
   provider = gtk_css_provider_new ();
-  file = g_file_new_for_uri ("resource:///sm/puri/phosh/stylesheet/adwaita-dark.css");
+  file = g_file_new_for_uri ("resource:///mobi/phosh/stylesheet/adwaita-dark.css");
 
   if (!gtk_css_provider_load_from_file (provider, file, &error)) {
     g_warning ("Failed to load CSS file: %s", error->message);
